@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"fmt"
+	"github.com/carlmjohnson/versioninfo"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/robinovitch61/wander/internal/dev"
 	"github.com/spf13/cobra"
@@ -15,8 +16,6 @@ type arg struct {
 }
 
 var (
-	version, sha string
-
 	// Used for flags.
 	cfgFile string
 
@@ -106,6 +105,21 @@ var (
 		cfgFileEnvVar: "wander_update_seconds",
 		description:   `Seconds between updates for job & allocation pages. Disable with "-1". Default "2"`,
 	}
+	jobColumnsArg = arg{
+		cliLong:       "job-columns",
+		cfgFileEnvVar: "wander_job_columns",
+		description:   `Columns to display for Jobs view - can reference Meta keys. Default "Job,Type,Namespace,Status,Count,Submitted,Since Submit"`,
+	}
+	allTaskColumnsArg = arg{
+		cliLong:       "all-tasks-columns",
+		cfgFileEnvVar: "wander_all_tasks_columns",
+		description:   `Columns to display for All Tasks view. Default "Job,Alloc ID,Task Group,Alloc Name,Task Name,State,Started,Finished,Uptime"`,
+	}
+	jobTaskColumnsArg = arg{
+		cliLong:       "tasks-for-job-columns",
+		cfgFileEnvVar: "wander_tasks_for_job_columns",
+		description:   `Columns to display for Tasks for Job view. Default "Alloc ID,Task Group,Alloc Name,Task Name,State,Started,Finished,Uptime"`,
+	}
 	logOffsetArg = arg{
 		cliShort:      "o",
 		cliLong:       "log-offset",
@@ -142,6 +156,16 @@ var (
 	logoColorArg = arg{
 		cfgFileEnvVar: "wander_logo_color",
 	}
+	startCompactArg = arg{
+		cliLong:       "compact-header",
+		cfgFileEnvVar: "wander_compact_header",
+		description:   `If "true", start with compact header. Default "false"`,
+	}
+	startAllTasksView = arg{
+		cliLong:       "start-all-tasks",
+		cfgFileEnvVar: "wander_start_all_tasks",
+		description:   `If "true", start in All Tasks view. Default "false"`,
+	}
 
 	description = `wander is a terminal application for Nomad by HashiCorp. It is used to
 view jobs, allocations, tasks, logs, and more, all from the terminal
@@ -152,7 +176,7 @@ in a productivity-focused UI.`
 		Short:   "A terminal application for Nomad by HashiCorp",
 		Long:    description,
 		Run:     mainEntrypoint,
-		Version: getVersion(),
+		Version: versioninfo.Short(),
 	}
 )
 
@@ -181,12 +205,17 @@ func init() {
 		tlsServerNameArg,
 		skipVerifyArg,
 		updateSecondsArg,
+		jobColumnsArg,
+		allTaskColumnsArg,
+		jobTaskColumnsArg,
 		logOffsetArg,
 		logTailArg,
 		copySavePathArg,
 		eventTopicsArg,
 		eventNamespaceArg,
 		eventJQQueryArg,
+		startCompactArg,
+		startAllTasksView,
 	} {
 		rootCmd.PersistentFlags().StringP(c.cliLong, c.cliShort, "", c.description)
 		viper.BindPFlag(c.cliLong, rootCmd.PersistentFlags().Lookup(c.cfgFileEnvVar))
