@@ -3,11 +3,13 @@ package cmd
 import (
 	"errors"
 	"fmt"
+	"github.com/carlmjohnson/versioninfo"
 	tea "github.com/charmbracelet/bubbletea"
+	"github.com/charmbracelet/ssh"
 	"github.com/charmbracelet/wish"
-	"github.com/gliderlabs/ssh"
 	"github.com/hashicorp/nomad/api"
 	"github.com/itchyny/gojq"
+	"github.com/robinovitch61/wander/internal/dev"
 	"github.com/robinovitch61/wander/internal/tui/components/app"
 	"github.com/robinovitch61/wander/internal/tui/constants"
 	"github.com/robinovitch61/wander/internal/tui/nomad"
@@ -20,16 +22,6 @@ import (
 	"time"
 )
 
-var (
-	// Version contains the application version number. It's set via ldflags
-	// in the .goreleaser.yaml file when building
-	Version = ""
-
-	// CommitSHA contains the SHA of the commit that this application was built
-	// against. It's set via ldflags in the .goreleaser.yaml file when building
-	CommitSHA = ""
-)
-
 func validateToken(token string) error {
 	if len(token) > 0 && len(token) != 36 {
 		return errors.New("token must be 36 characters")
@@ -226,6 +218,36 @@ func retrieveUpdateSeconds(cmd *cobra.Command) int {
 	return updateSeconds
 }
 
+func retrieveJobColumns(cmd *cobra.Command) []string {
+	columnsString := retrieveWithDefault(cmd, jobColumnsArg, "Job,Type,Namespace,Status,Count,Submitted,Since Submit")
+	split := strings.Split(columnsString, ",")
+	var trimmed []string
+	for _, s := range split {
+		trimmed = append(trimmed, strings.TrimSpace(s))
+	}
+	return trimmed
+}
+
+func retrieveAllTaskColumns(cmd *cobra.Command) []string {
+	columnsString := retrieveWithDefault(cmd, allTaskColumnsArg, "Job,Alloc ID,Task Group,Alloc Name,Task Name,State,Started,Finished,Uptime")
+	split := strings.Split(columnsString, ",")
+	var trimmed []string
+	for _, s := range split {
+		trimmed = append(trimmed, strings.TrimSpace(s))
+	}
+	return trimmed
+}
+
+func retrieveJobTaskColumns(cmd *cobra.Command) []string {
+	columnsString := retrieveWithDefault(cmd, jobTaskColumnsArg, "Alloc ID,Task Group,Alloc Name,Task Name,State,Started,Finished,Uptime")
+	split := strings.Split(columnsString, ",")
+	var trimmed []string
+	for _, s := range split {
+		trimmed = append(trimmed, strings.TrimSpace(s))
+	}
+	return trimmed
+}
+
 func retrieveLogOffset(cmd *cobra.Command) int {
 	logOffsetString := retrieveWithDefault(cmd, logOffsetArg, "1000000")
 	logOffset, err := strconv.Atoi(logOffsetString)
@@ -241,6 +263,16 @@ func retrieveLogTail(cmd *cobra.Command) bool {
 	return trueIfTrue(v)
 }
 
+func retrieveStartCompact(cmd *cobra.Command) bool {
+	v := retrieveWithDefault(cmd, startCompactArg, "false")
+	return trueIfTrue(v)
+}
+
+func retrieveStartAllTasksView(cmd *cobra.Command) bool {
+	v := retrieveWithDefault(cmd, startAllTasksView, "false")
+	return trueIfTrue(v)
+}
+
 // customLoggingMiddleware provides basic connection logging. Connects are logged with the
 // remote address, invoked command, TERM setting, window dimensions and if the
 // auth was public key based. Disconnect will log the remote address and
@@ -284,11 +316,16 @@ func setup(cmd *cobra.Command, overrideToken string) (app.Model, []tea.ProgramOp
 	eventNamespace := retrieveEventNamespace(cmd)
 	eventJQQuery := retrieveEventJQQuery(cmd)
 	updateSeconds := retrieveUpdateSeconds(cmd)
+	jobColumns := retrieveJobColumns(cmd)
+	allTaskColumns := retrieveAllTaskColumns(cmd)
+	jobTaskColumns := retrieveJobTaskColumns(cmd)
 	logoColor := retrieveNonCLIWithDefault(logoColorArg, "")
+	startCompact := retrieveStartCompact(cmd)
+	startAllTasksView := retrieveStartAllTasksView(cmd)
 
+	dev.Debug(fmt.Sprintf("Version: %s, %s, %s", versioninfo.Version, versioninfo.Revision, versioninfo.Short()))
 	initialModel := app.InitialModel(app.Config{
-		Version:   Version,
-		SHA:       CommitSHA,
+		Version:   versioninfo.Short(),
 		URL:       nomadAddr,
 		Token:     nomadToken,
 		Region:    region,
@@ -312,15 +349,13 @@ func setup(cmd *cobra.Command, overrideToken string) (app.Model, []tea.ProgramOp
 			Namespace: eventNamespace,
 			JQQuery:   eventJQQuery,
 		},
-		UpdateSeconds: time.Second * time.Duration(updateSeconds),
-		LogoColor:     logoColor,
+		UpdateSeconds:     time.Second * time.Duration(updateSeconds),
+		JobColumns:        jobColumns,
+		AllTaskColumns:    allTaskColumns,
+		JobTaskColumns:    jobTaskColumns,
+		LogoColor:         logoColor,
+		StartCompact:      startCompact,
+		StartAllTasksView: startAllTasksView,
 	})
 	return initialModel, []tea.ProgramOption{tea.WithAltScreen()}
 }
-
-func getVersion() string {
-	if Version == "" {
-		return constants.NoVersionString
-	}
-	return Version
-}
