@@ -38,7 +38,7 @@ type LogConfig struct {
 }
 
 type Config struct {
-	Version, SHA                  string
+	Version                       string
 	URL, Token, Region, Namespace string
 	HTTPAuth                      string
 	TLS                           TLSConfig
@@ -46,7 +46,12 @@ type Config struct {
 	Log                           LogConfig
 	CopySavePath                  bool
 	UpdateSeconds                 time.Duration
+	JobColumns                    []string
+	AllTaskColumns                []string
+	JobTaskColumns                []string
 	LogoColor                     string
+	StartCompact                  bool
+	StartAllTasksView             bool
 }
 
 type Model struct {
@@ -54,9 +59,11 @@ type Model struct {
 	client api.Client
 
 	header      header.Model
+	compact     bool
 	currentPage nomad.Page
 	pageModels  map[nomad.Page]*page.Model
 
+	inJobsMode   bool
 	jobID        string
 	jobNamespace string
 	alloc        api.Allocation
@@ -68,6 +75,7 @@ type Model struct {
 
 	eventsStream nomad.EventsStream
 	event        string
+	meta         map[string]string
 
 	logsStream      nomad.LogsStream
 	lastLogFinished bool
@@ -85,19 +93,22 @@ type Model struct {
 
 func InitialModel(c Config) Model {
 	firstPage := nomad.JobsPage
+	if c.StartAllTasksView {
+		firstPage = nomad.AllTasksPage
+	}
 	initialHeader := header.New(
 		constants.LogoString,
 		c.LogoColor,
 		c.URL,
-		getVersionString(c.Version, c.SHA),
-		nomad.GetPageKeyHelp(firstPage, false, false, false, false, false, false, nomad.StdOut),
+		c.Version,
+		nomad.GetPageKeyHelp(firstPage, false, false, false, false, false, false, nomad.StdOut, false, !c.StartAllTasksView),
 	)
-
 	return Model{
 		config:      c,
 		header:      initialHeader,
 		currentPage: firstPage,
 		updateID:    nextUpdateID(),
+		inJobsMode:  !c.StartAllTasksView,
 	}
 }
 
@@ -186,10 +197,15 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 
 	case nomad.EventsStreamMsg:
 		if m.currentPage == nomad.JobEventsPage || m.currentPage == nomad.AllocEventsPage || m.currentPage == nomad.AllEventsPage {
-			if fmt.Sprint(msg.Topics) == fmt.Sprint(m.eventsStream.Topics) && msg.CompleteValue != "{}" {
+			if fmt.Sprint(msg.Topics) == fmt.Sprint(m.eventsStream.Topics) {
 				// sticky scroll down, i.e. if at bottom already, keep scrolling to bottom as new ones are added
 				scrollDown := m.getCurrentPageModel().ViewportSelectionAtBottom()
-				m.getCurrentPageModel().AppendToViewport([]page.Row{{Key: msg.CompleteValue, Row: msg.JQValue}}, true)
+				for _, event := range msg.Events {
+					if event.CompleteValue == "{}" {
+						continue
+					}
+					m.getCurrentPageModel().AppendToViewport([]page.Row{{Key: event.CompleteValue, Row: event.JQValue}}, true)
+				}
 				if scrollDown {
 					m.getCurrentPageModel().ScrollViewportToBottom()
 				}
@@ -303,6 +319,12 @@ func (m *Model) initialize() error {
 		m.pageModels[k] = &p
 	}
 
+	if m.config.StartCompact {
+		m.toggleCompact()
+	}
+
+	m.getCurrentPageModel().SetFilterPrefix(m.getFilterPrefix(m.currentPage))
+
 	m.initialized = true
 	return nil
 }
@@ -354,6 +376,10 @@ func (m *Model) handleKeyMsg(msg tea.KeyMsg) tea.Cmd {
 
 	if !m.currentPageFilterFocused() && !m.currentPageViewportSaving() {
 		switch {
+		case key.Matches(msg, keymap.KeyMap.Compact):
+			m.toggleCompact()
+			return nil
+
 		case key.Matches(msg, keymap.KeyMap.Forward):
 			if selectedPageRow, err := m.getCurrentPageModel().GetSelectedPageRow(); err == nil {
 				switch m.currentPage {
@@ -361,15 +387,17 @@ func (m *Model) handleKeyMsg(msg tea.KeyMsg) tea.Cmd {
 					m.jobID, m.jobNamespace = nomad.JobIDAndNamespaceFromKey(selectedPageRow.Key)
 				case nomad.JobEventsPage, nomad.AllocEventsPage, nomad.AllEventsPage:
 					m.event = selectedPageRow.Key
-				case nomad.AllocationsPage:
-					allocInfo, err := nomad.AllocationInfoFromKey(selectedPageRow.Key)
-					if err != nil {
-						m.err = err
-						return nil
-					}
-					m.alloc, m.taskName = allocInfo.Alloc, allocInfo.TaskName
 				case nomad.LogsPage:
 					m.logline = selectedPageRow.Row
+				default:
+					if m.currentPage.ShowsTasks() {
+						taskInfo, err := nomad.TaskInfoFromKey(selectedPageRow.Key)
+						if err != nil {
+							m.err = err
+							return nil
+						}
+						m.alloc, m.taskName = taskInfo.Alloc, taskInfo.TaskName
+					}
 				}
 
 				nextPage := m.currentPage.Forward()
@@ -389,7 +417,7 @@ func (m *Model) handleKeyMsg(msg tea.KeyMsg) tea.Cmd {
 					m.getCurrentPageModel().SetDoesNeedNewInput()
 				}
 
-				backPage := m.currentPage.Backward()
+				backPage := m.currentPage.Backward(m.inJobsMode)
 				if backPage != m.currentPage {
 					m.setPage(backPage)
 					cmds = append(cmds, m.getCurrentPageCmd())
@@ -406,14 +434,14 @@ func (m *Model) handleKeyMsg(msg tea.KeyMsg) tea.Cmd {
 
 		if key.Matches(msg, keymap.KeyMap.Exec) {
 			if selectedPageRow, err := m.getCurrentPageModel().GetSelectedPageRow(); err == nil {
-				if m.currentPage == nomad.AllocationsPage {
-					allocInfo, err := nomad.AllocationInfoFromKey(selectedPageRow.Key)
+				if m.currentPage.ShowsTasks() {
+					taskInfo, err := nomad.TaskInfoFromKey(selectedPageRow.Key)
 					if err != nil {
 						m.err = err
 						return nil
 					}
-					if allocInfo.Running {
-						m.alloc, m.taskName = allocInfo.Alloc, allocInfo.TaskName
+					if taskInfo.Running {
+						m.alloc, m.taskName = taskInfo.Alloc, taskInfo.TaskName
 						m.setPage(nomad.ExecPage)
 						return m.getCurrentPageCmd()
 					}
@@ -428,15 +456,17 @@ func (m *Model) handleKeyMsg(msg tea.KeyMsg) tea.Cmd {
 					m.jobID, m.jobNamespace = nomad.JobIDAndNamespaceFromKey(selectedPageRow.Key)
 					m.setPage(nomad.JobSpecPage)
 					return m.getCurrentPageCmd()
-				case nomad.AllocationsPage:
-					allocInfo, err := nomad.AllocationInfoFromKey(selectedPageRow.Key)
-					if err != nil {
-						m.err = err
-						return nil
+				default:
+					if m.currentPage.ShowsTasks() {
+						taskInfo, err := nomad.TaskInfoFromKey(selectedPageRow.Key)
+						if err != nil {
+							m.err = err
+							return nil
+						}
+						m.alloc, m.taskName = taskInfo.Alloc, taskInfo.TaskName
+						m.setPage(nomad.AllocSpecPage)
+						return m.getCurrentPageCmd()
 					}
-					m.alloc, m.taskName = allocInfo.Alloc, allocInfo.TaskName
-					m.setPage(nomad.AllocSpecPage)
-					return m.getCurrentPageCmd()
 				}
 			}
 		}
@@ -449,14 +479,38 @@ func (m *Model) handleKeyMsg(msg tea.KeyMsg) tea.Cmd {
 			}
 		}
 
-		if key.Matches(msg, keymap.KeyMap.AllocEvents) && m.currentPage == nomad.AllocationsPage {
+		if key.Matches(msg, keymap.KeyMap.TasksMode) && m.currentPage == nomad.JobsPage {
+			if m.inJobsMode {
+				m.setPage(nomad.AllTasksPage)
+				m.inJobsMode = false
+				return m.getCurrentPageCmd()
+			}
+		}
+
+		if key.Matches(msg, keymap.KeyMap.JobsMode) && m.currentPage == nomad.AllTasksPage {
+			if !m.inJobsMode {
+				m.setPage(nomad.JobsPage)
+				m.inJobsMode = true
+				return m.getCurrentPageCmd()
+			}
+		}
+
+		if key.Matches(msg, keymap.KeyMap.JobMeta) && m.currentPage == nomad.JobsPage {
 			if selectedPageRow, err := m.getCurrentPageModel().GetSelectedPageRow(); err == nil {
-				allocInfo, err := nomad.AllocationInfoFromKey(selectedPageRow.Key)
+				m.jobID, m.jobNamespace = nomad.JobIDAndNamespaceFromKey(selectedPageRow.Key)
+				m.setPage(nomad.JobMetaPage)
+				return m.getCurrentPageCmd()
+			}
+		}
+
+		if key.Matches(msg, keymap.KeyMap.AllocEvents) && m.currentPage.ShowsTasks() {
+			if selectedPageRow, err := m.getCurrentPageModel().GetSelectedPageRow(); err == nil {
+				taskInfo, err := nomad.TaskInfoFromKey(selectedPageRow.Key)
 				if err != nil {
 					m.err = err
 					return nil
 				}
-				m.alloc, m.taskName = allocInfo.Alloc, allocInfo.TaskName
+				m.alloc, m.taskName = taskInfo.Alloc, taskInfo.TaskName
 				m.setPage(nomad.AllocEventsPage)
 				return m.getCurrentPageCmd()
 			}
@@ -547,19 +601,34 @@ func (m *Model) setInPty(inPty bool) {
 }
 
 func (m *Model) updateKeyHelp() {
-	m.header.KeyHelp = nomad.GetPageKeyHelp(m.currentPage, m.currentPageFilterFocused(), m.currentPageFilterApplied(), m.currentPageViewportSaving(), m.getCurrentPageModel().EnteringInput(), m.inPty, m.webSocketConnected, m.logType)
+	newKeyHelp := nomad.GetPageKeyHelp(m.currentPage, m.currentPageFilterFocused(), m.currentPageFilterApplied(), m.currentPageViewportSaving(), m.getCurrentPageModel().EnteringInput(), m.inPty, m.webSocketConnected, m.logType, m.compact, m.inJobsMode)
+	m.header.SetKeyHelp(newKeyHelp)
+}
+
+func (m *Model) toggleCompact() {
+	m.compact = !m.compact
+	m.header.ToggleCompact()
+	m.updateKeyHelp()
+	for _, pm := range m.pageModels {
+		pm.ToggleCompact()
+	}
+	m.setPageWindowSize()
 }
 
 func (m Model) getCurrentPageCmd() tea.Cmd {
 	switch m.currentPage {
 	case nomad.JobsPage:
-		return nomad.FetchJobs(m.client)
+		return nomad.FetchJobs(m.client, m.config.JobColumns)
+	case nomad.AllTasksPage:
+		return nomad.FetchAllTasks(m.client, m.config.AllTaskColumns)
 	case nomad.JobSpecPage:
 		return nomad.FetchJobSpec(m.client, m.jobID, m.jobNamespace)
 	case nomad.JobEventsPage:
 		return nomad.FetchEventsStream(m.client, nomad.TopicsForJob(m.config.Event.Topics, m.jobID), m.jobNamespace, nomad.JobEventsPage)
 	case nomad.JobEventPage:
 		return nomad.PrettifyLine(m.event, nomad.JobEventPage)
+	case nomad.JobMetaPage:
+		return nomad.FetchJobMeta(m.client, m.jobID, m.jobNamespace)
 	case nomad.AllocEventsPage:
 		return nomad.FetchEventsStream(m.client, nomad.TopicsForAlloc(m.config.Event.Topics, m.alloc.ID), m.jobNamespace, nomad.AllocEventsPage)
 	case nomad.AllocEventPage:
@@ -568,8 +637,8 @@ func (m Model) getCurrentPageCmd() tea.Cmd {
 		return nomad.FetchEventsStream(m.client, m.config.Event.Topics, m.config.Event.Namespace, nomad.AllEventsPage)
 	case nomad.AllEventPage:
 		return nomad.PrettifyLine(m.event, nomad.AllEventPage)
-	case nomad.AllocationsPage:
-		return nomad.FetchAllocations(m.client, m.jobID, m.jobNamespace)
+	case nomad.JobTasksPage:
+		return nomad.FetchTasksForJob(m.client, m.jobID, m.jobNamespace, m.config.JobTaskColumns)
 	case nomad.ExecPage:
 		return nomad.LoadExecPage()
 	case nomad.AllocSpecPage:
@@ -604,16 +673,5 @@ func (m Model) currentPageViewportSaving() bool {
 }
 
 func (m Model) getFilterPrefix(page nomad.Page) string {
-	return page.GetFilterPrefix(m.jobID, m.taskName, m.alloc.ID, m.config.Event.Topics, m.config.Event.Namespace)
-}
-
-func getVersionString(v, s string) string {
-	if v == "" {
-		return constants.NoVersionString
-	}
-	if len(s) >= 7 {
-		s = s[:7]
-	}
-
-	return fmt.Sprintf("%s (%s)", v, s)
+	return page.GetFilterPrefix(m.config.Namespace, m.jobID, m.taskName, m.alloc.Name, m.alloc.ID, m.config.Event.Topics, m.config.Event.Namespace)
 }
