@@ -22,14 +22,14 @@ const ExecWebSocketClosed = "> connection closed <"
 
 const ExecWebSocketHeartbeatDuration = time.Second * 10
 
-const TablePadding = "    "
+const TablePadding = "   "
 
-var JobsViewportConditionalStyle = map[string]lipgloss.Style{
+var JobsTableStatusStyles = map[string]lipgloss.Style{
 	TablePadding + "pending" + TablePadding: style.JobRowPending,
 	TablePadding + "dead" + TablePadding:    style.JobRowDead,
 }
 
-var AllocationsViewportConditionalStyle = JobsViewportConditionalStyle
+var TasksTableStatusStyles = JobsTableStatusStyles
 
 const DefaultPageInput = "/bin/sh"
 
@@ -38,5 +38,5 @@ const DefaultEventJQQuery = `.Events[] | {
 	"2:Topic": .Topic,
 	"3:Type": .Type,
 	"4:Name": .Payload | (.Job // .Allocation // .Deployment // .Evaluation) | (.JobID // .ID),
-	"5:AllocID": .Payload | (.Allocation // .Deployment // .Evaluation).ID[:8]
+	"5:ID": .Payload | (.Job.ID // (.Allocation // .Deployment // .Evaluation).ID[:8])
 }`
