@@ -20,14 +20,16 @@ type Page int8
 const (
 	Unset Page = iota
 	JobsPage
+	AllTasksPage
 	JobSpecPage
 	JobEventsPage
 	JobEventPage
+	JobMetaPage
 	AllocEventsPage
 	AllocEventPage
 	AllEventsPage
 	AllEventPage
-	AllocationsPage
+	JobTasksPage
 	ExecPage
 	AllocSpecPage
 	LogsPage
@@ -38,9 +40,15 @@ func GetAllPageConfigs(width, height int, copySavePath bool) map[Page]page.Confi
 	return map[Page]page.Config{
 		JobsPage: {
 			Width: width, Height: height,
-			FilterPrefix: "Jobs", LoadingString: JobsPage.LoadingString(),
-			CopySavePath: copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
-			ViewportConditionalStyle: constants.JobsViewportConditionalStyle,
+			LoadingString: JobsPage.LoadingString(),
+			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			ViewportConditionalStyle: constants.JobsTableStatusStyles,
+		},
+		AllTasksPage: {
+			Width: width, Height: height,
+			LoadingString: AllTasksPage.LoadingString(),
+			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
+			ViewportConditionalStyle: constants.TasksTableStatusStyles,
 		},
 		JobSpecPage: {
 			Width: width, Height: height,
@@ -57,6 +65,11 @@ func GetAllPageConfigs(width, height int, copySavePath bool) map[Page]page.Confi
 			LoadingString: JobEventPage.LoadingString(),
 			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
 		},
+		JobMetaPage: {
+			Width: width, Height: height,
+			LoadingString: JobMetaPage.LoadingString(),
+			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
+		},
 		AllocEventsPage: {
 			Width: width, Height: height,
 			LoadingString: AllocEventsPage.LoadingString(),
@@ -77,11 +90,11 @@ func GetAllPageConfigs(width, height int, copySavePath bool) map[Page]page.Confi
 			LoadingString: AllEventPage.LoadingString(),
 			CopySavePath:  copySavePath, SelectionEnabled: false, WrapText: true, RequestInput: false,
 		},
-		AllocationsPage: {
+		JobTasksPage: {
 			Width: width, Height: height,
-			LoadingString: AllocationsPage.LoadingString(),
+			LoadingString: JobTasksPage.LoadingString(),
 			CopySavePath:  copySavePath, SelectionEnabled: true, WrapText: false, RequestInput: false,
-			ViewportConditionalStyle: constants.AllocationsViewportConditionalStyle,
+			ViewportConditionalStyle: constants.TasksTableStatusStyles,
 		},
 		ExecPage: {
 			Width: width, Height: height,
@@ -126,6 +139,16 @@ func (p Page) DoesReload() bool {
 	return true
 }
 
+func (p Page) ShowsTasks() bool {
+	taskPages := []Page{AllTasksPage, JobTasksPage}
+	for _, taskPage := range taskPages {
+		if taskPage == p {
+			return true
+		}
+	}
+	return false
+}
+
 func (p Page) doesUpdate() bool {
 	noUpdatePages := []Page{
 		LoglinePage,     // doesn't load
@@ -154,16 +177,22 @@ func (p Page) String() string {
 		return "undefined"
 	case JobsPage:
 		return "jobs"
+	case AllTasksPage:
+		return "all tasks"
 	case JobSpecPage:
 		return "job spec"
-	case JobEventsPage, AllocEventsPage:
+	case JobEventsPage:
+		return "job events"
+	case AllocEventsPage:
 		return "events"
+	case JobMetaPage:
+		return "meta"
 	case AllEventsPage:
 		return "all events"
 	case JobEventPage, AllocEventPage, AllEventPage:
 		return "event"
-	case AllocationsPage:
-		return "allocations"
+	case JobTasksPage:
+		return "tasks"
 	case ExecPage:
 		return "exec"
 	case AllocSpecPage:
@@ -183,14 +212,16 @@ func (p Page) LoadingString() string {
 func (p Page) Forward() Page {
 	switch p {
 	case JobsPage:
-		return AllocationsPage
+		return JobTasksPage
+	case AllTasksPage:
+		return LogsPage
 	case JobEventsPage:
 		return JobEventPage
 	case AllocEventsPage:
 		return AllocEventPage
 	case AllEventsPage:
 		return AllEventPage
-	case AllocationsPage:
+	case JobTasksPage:
 		return LogsPage
 	case LogsPage:
 		return LoglinePage
@@ -198,7 +229,14 @@ func (p Page) Forward() Page {
 	return p
 }
 
-func (p Page) Backward() Page {
+func returnToPage(inJobsMode bool) Page {
+	if inJobsMode {
+		return JobTasksPage
+	}
+	return AllTasksPage
+}
+
+func (p Page) Backward(inJobsMode bool) Page {
 	switch p {
 	case JobSpecPage:
 		return JobsPage
@@ -206,56 +244,77 @@ func (p Page) Backward() Page {
 		return JobsPage
 	case JobEventPage:
 		return JobEventsPage
+	case JobMetaPage:
+		return JobsPage
 	case AllocEventsPage:
-		return AllocationsPage
+		return returnToPage(inJobsMode)
 	case AllocEventPage:
 		return AllocEventsPage
 	case AllEventsPage:
 		return JobsPage
 	case AllEventPage:
 		return AllEventsPage
-	case AllocationsPage:
+	case JobTasksPage:
 		return JobsPage
 	case ExecPage:
-		return AllocationsPage
+		return returnToPage(inJobsMode)
 	case AllocSpecPage:
-		return AllocationsPage
+		return returnToPage(inJobsMode)
 	case LogsPage:
-		return AllocationsPage
+		return returnToPage(inJobsMode)
 	case LoglinePage:
 		return LogsPage
 	}
 	return p
 }
 
-func (p Page) GetFilterPrefix(jobID, taskName, allocID string, eventTopics Topics, eventNamespace string) string {
+func allocEventFilterPrefix(allocName, allocID string) string {
+	return fmt.Sprintf("%s %s", style.Bold.Render(allocName), formatter.ShortAllocID(allocID))
+}
+
+func taskFilterPrefix(taskName, allocName string) string {
+	return fmt.Sprintf("%s in %s", style.Bold.Render(taskName), allocName)
+}
+
+func namespaceFilterPrefix(namespace string) string {
+	if namespace == "*" {
+		return "All Namespaces"
+	}
+	return fmt.Sprintf("Namespace %s", style.Bold.Render(namespace))
+}
+
+func (p Page) GetFilterPrefix(namespace, jobID, taskName, allocName, allocID string, eventTopics Topics, eventNamespace string) string {
 	switch p {
 	case JobsPage:
-		return "Jobs"
+		return fmt.Sprintf("Jobs in %s", namespaceFilterPrefix(namespace))
+	case AllTasksPage:
+		return fmt.Sprintf("All Tasks in %s", namespaceFilterPrefix(namespace))
 	case JobSpecPage:
-		return fmt.Sprintf("Job Spec for %s", style.Bold.Render(jobID))
+		return fmt.Sprintf("Spec for Job %s", style.Bold.Render(jobID))
 	case JobEventsPage:
-		return fmt.Sprintf("Events for %s (%s)", jobID, getTopicNames(eventTopics))
+		return fmt.Sprintf("Events for Job %s (%s)", style.Bold.Render(jobID), getTopicNames(eventTopics))
 	case JobEventPage:
-		return fmt.Sprintf("Event for %s", jobID)
+		return fmt.Sprintf("Event for Job %s", style.Bold.Render(jobID))
+	case JobMetaPage:
+		return fmt.Sprintf("Meta for Job %s", jobID)
 	case AllocEventsPage:
-		return fmt.Sprintf("Events for %s %s", style.Bold.Render(jobID), formatter.ShortAllocID(allocID))
+		return fmt.Sprintf("Events for Allocation %s", allocEventFilterPrefix(allocName, allocID))
 	case AllocEventPage:
-		return fmt.Sprintf("Event for %s %s", style.Bold.Render(jobID), formatter.ShortAllocID(allocID))
+		return fmt.Sprintf("Event for Allocation %s", allocEventFilterPrefix(allocName, allocID))
 	case AllEventsPage:
-		return fmt.Sprintf("All Events in %s (%s)", eventNamespace, formatEventTopics(eventTopics))
+		return fmt.Sprintf("All Events in Namespace %s (%s)", eventNamespace, formatEventTopics(eventTopics))
 	case AllEventPage:
 		return fmt.Sprintf("Event")
-	case AllocationsPage:
-		return fmt.Sprintf("Allocations for %s", style.Bold.Render(jobID))
+	case JobTasksPage:
+		return fmt.Sprintf("Tasks for Job %s", style.Bold.Render(jobID))
 	case ExecPage:
-		return fmt.Sprintf("Exec for %s %s", style.Bold.Render(taskName), formatter.ShortAllocID(allocID))
+		return fmt.Sprintf("Exec for Task %s", taskFilterPrefix(taskName, allocName))
 	case AllocSpecPage:
-		return fmt.Sprintf("Allocation Spec for %s %s", style.Bold.Render(taskName), formatter.ShortAllocID(allocID))
+		return fmt.Sprintf("Spec for Allocation %s %s", style.Bold.Render(allocName), formatter.ShortAllocID(allocID))
 	case LogsPage:
-		return fmt.Sprintf("Logs for %s %s", style.Bold.Render(taskName), formatter.ShortAllocID(allocID))
+		return fmt.Sprintf("Logs for Task %s", taskFilterPrefix(taskName, allocName))
 	case LoglinePage:
-		return fmt.Sprintf("Log Line for %s %s", style.Bold.Render(taskName), formatter.ShortAllocID(allocID))
+		return fmt.Sprintf("Log Line for Task %s", taskFilterPrefix(taskName, allocName))
 	default:
 		panic("page not found")
 	}
@@ -295,7 +354,7 @@ func UpdatePageDataWithDelay(id int, p Page, d time.Duration) tea.Cmd {
 func getShortHelp(bindings []key.Binding) string {
 	var output string
 	for _, km := range bindings {
-		output += style.KeyHelpKey.Render(km.Help().Key) + " " + style.KeyHelpDescription.Render(km.Help().Desc) + "    "
+		output += style.KeyHelpKey.Render(km.Help().Key) + " " + style.KeyHelpDescription.Render(km.Help().Desc) + "  "
 	}
 	output = strings.TrimSpace(output)
 	return output
@@ -305,11 +364,26 @@ func changeKeyHelp(k *key.Binding, h string) {
 	k.SetHelp(k.Help().Key, h)
 }
 
-func GetPageKeyHelp(currentPage Page, filterFocused, filterApplied, saving, enteringInput, inPty, webSocketConnected bool, logType LogType) string {
+func GetPageKeyHelp(
+	currentPage Page,
+	filterFocused, filterApplied, saving, enteringInput, inPty, webSocketConnected bool,
+	logType LogType,
+	compact, inJobsMode bool,
+) string {
+	if compact {
+		changeKeyHelp(&keymap.KeyMap.Compact, "expand header")
+		return getShortHelp([]key.Binding{keymap.KeyMap.Compact})
+	} else {
+		changeKeyHelp(&keymap.KeyMap.Compact, "compact")
+	}
+
 	firstRow := []key.Binding{keymap.KeyMap.Exit}
 
-	if currentPage.DoesReload() && !saving && !filterFocused {
-		firstRow = append(firstRow, keymap.KeyMap.Reload)
+	if !saving && !filterFocused {
+		firstRow = append(firstRow, keymap.KeyMap.Compact)
+		if currentPage.DoesReload() {
+			firstRow = append(firstRow, keymap.KeyMap.Reload)
+		}
 	}
 
 	viewportKeyMap := viewport.GetKeyMap()
@@ -325,12 +399,17 @@ func GetPageKeyHelp(currentPage Page, filterFocused, filterApplied, saving, ente
 	if filterApplied {
 		changeKeyHelp(&keymap.KeyMap.Back, "remove filter")
 		fourthRow = append(fourthRow, keymap.KeyMap.Back)
-	} else if prevPage := currentPage.Backward(); prevPage != currentPage {
-		changeKeyHelp(&keymap.KeyMap.Back, fmt.Sprintf("%s", currentPage.Backward().String()))
+	} else if prevPage := currentPage.Backward(inJobsMode); prevPage != currentPage {
+		changeKeyHelp(&keymap.KeyMap.Back, fmt.Sprintf("%s", currentPage.Backward(inJobsMode).String()))
 		fourthRow = append(fourthRow, keymap.KeyMap.Back)
 	}
 
-	if currentPage == JobsPage || currentPage == AllocationsPage {
+	if currentPage == JobsPage || currentPage.ShowsTasks() {
+		if currentPage == JobsPage {
+			fourthRow = append(fourthRow, keymap.KeyMap.TasksMode)
+		} else if currentPage == AllTasksPage {
+			fourthRow = append(fourthRow, keymap.KeyMap.JobsMode)
+		}
 		fourthRow = append(fourthRow, keymap.KeyMap.Spec)
 	} else if currentPage == LogsPage {
 		if logType == StdOut {
@@ -343,9 +422,10 @@ func GetPageKeyHelp(currentPage Page, filterFocused, filterApplied, saving, ente
 	if currentPage == JobsPage {
 		fourthRow = append(fourthRow, keymap.KeyMap.JobEvents)
 		fourthRow = append(fourthRow, keymap.KeyMap.AllEvents)
+		fourthRow = append(fourthRow, keymap.KeyMap.JobMeta)
 	}
 
-	if currentPage == AllocationsPage {
+	if currentPage.ShowsTasks() {
 		fourthRow = append(fourthRow, keymap.KeyMap.AllocEvents)
 		fourthRow = append(fourthRow, keymap.KeyMap.Exec)
 	}
